pub struct CompInfo {
pub component_id: i32,
pub component_index: i32,
pub h_samp_factor: i32,
pub v_samp_factor: i32,
pub quant_tbl_no: i32,
pub dc_tbl_no: i32,
pub ac_tbl_no: i32,
pub width_in_blocks: u32,
pub height_in_blocks: u32,
pub quant_table: *mut JQUANT_TBL,
/* private fields */
}Fields
component_id: i32identifier for this component (0..255)
component_index: i32its index in SOF or cinfo->comp_info[]
h_samp_factor: i32horizontal sampling factor (1..4)
v_samp_factor: i32vertical sampling factor (1..4)
quant_tbl_no: i32quantization table selector (0..3)
dc_tbl_no: i32DC entropy table selector (0..3)
These values may vary between scans. For compression, they must be supplied by parameter setup; for decompression, they are read from the SOS marker. The decompressor output side may not use these variables.
ac_tbl_no: i32AC entropy table selector (0..3)
width_in_blocks: u32height_in_blocks: u32quant_table: *mut JQUANT_TBLTrait Implementations
Sourceimpl CompInfoExt for CompInfo
impl CompInfoExt for CompInfo
fn qtable(&self) -> Option<QTable>
Sourcefn sampling(&self) -> (u8, u8)
fn sampling(&self) -> (u8, u8)
h,v samplinig (1..4). Number of pixels per sample (may be opposite of what you expect!)
Sourcefn row_stride(&self) -> usize
fn row_stride(&self) -> usize
Number of pixels per row, including padding to MCU
Sourcefn col_stride(&self) -> usize
fn col_stride(&self) -> usize
Total height, including padding to MCU
fn width_in_blocks(&self) -> usize
fn height_in_blocks(&self) -> usize
Sourceimpl Default for jpeg_component_info
impl Default for jpeg_component_info
Sourcefn default() -> jpeg_component_info
fn default() -> jpeg_component_info
Returns the “default value” for a type. Read more